@@ -428,23 +428,8 @@ void patterncommands(void)
         }
       }
     }
-    break;
 
-    case KEY_B:
-    if (shiftpressed && editmode == EDIT_PATTERN)
-    {
-      for (c = 0; c < cmdcopyrows; c++)
-      {
-        if (eppos >= pattlen[epnum[epchn]]) break;
-        pattern[epnum[epchn]][eppos*4+2] = cmdcopybuffer[c*4+2];
-        pattern[epnum[epchn]][eppos*4+3] = cmdcopybuffer[c*4+3];
-        eppos++;
-      }
-    }
-    break;
-
-    case KEY_I:
-    if (shiftpressed)
+    if (fnpressed)
     {
       int d, e;
       char temp;
@@ -499,6 +484,20 @@ void patterncommands(void)
         }
       }
     }
+
+    break;
+
+    case KEY_B:
+    if (shiftpressed && editmode == EDIT_PATTERN)
+    {
+      for (c = 0; c < cmdcopyrows; c++)
+      {
+        if (eppos >= pattlen[epnum[epchn]]) break;
+        pattern[epnum[epchn]][eppos*4+2] = cmdcopybuffer[c*4+2];
+        pattern[epnum[epchn]][eppos*4+3] = cmdcopybuffer[c*4+3];
+        eppos++;
+      }
+    }
     break;
 
     case KEY_S:
